@@ -1,5 +1,5 @@
 package Beam::Runner::Command::list;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: List the available containers and services
 
 #pod =head1 SYNOPSIS
@@ -10,8 +10,9 @@ our $VERSION = '0.002';
 #pod =head1 DESCRIPTION
 #pod
 #pod List the available containers found in the directories defined in
-#pod C<BEAM_PATH>, or list the runnable services found in the given
-#pod container.
+#pod C<BEAM_PATH>, and list the runnable services found in them. Also show
+#pod the C<$summary> from the container file, and the abstract from every
+#pod service.
 #pod
 #pod When listing services, this command must load every single class
 #pod referenced in the container, but it will not instanciate any object.
@@ -24,11 +25,14 @@ our $VERSION = '0.002';
 
 use strict;
 use warnings;
-use List::Util qw( any );
+use List::Util qw( any max );
 use Path::Tiny qw( path );
 use Module::Runtime qw( use_module );
 use Beam::Wire;
 use Beam::Runner::Util qw( find_container_path );
+use Pod::Find qw( pod_where );
+use Pod::Simple::SimpleTree;
+use Term::ANSIColor qw( color );
 
 # The extensions to remove to show the container's name
 my @EXTS = grep { $_ } @Beam::Runner::Util::EXTS;
@@ -67,6 +71,8 @@ sub _list_containers {
     my ( $class ) = @_;
     die "Cannot list containers: BEAM_PATH environment variable not set\n"
         unless $ENV{BEAM_PATH};
+
+    my %containers;
     for my $dir ( split /:/, $ENV{BEAM_PATH} ) {
         my $p = path( $dir );
         my $i = $p->iterator( { recurse => 1, follow_symlinks => 1 } );
@@ -75,9 +81,16 @@ sub _list_containers {
             next unless $file =~ $EXT_RE;
             my $name = $file->relative( $p );
             $name =~ s/$EXT_RE//;
-            print "$name\n";
+            $containers{ $name } ||= $file;
         }
     }
+
+    my @container_names = sort keys %containers;
+    for my $i ( 0..$#container_names ) {
+        $class->_list_services( $containers{ $container_names[ $i ] } );
+        print "\n" unless $i == $#container_names;
+    }
+
     return 0;
 }
 
@@ -92,16 +105,23 @@ sub _list_containers {
 sub _list_services {
     my ( $class, $container ) = @_;
     my $path = find_container_path( $container );
+    my $cname = $path->basename( @EXTS );
     my $wire = Beam::Wire->new(
         file => $path,
     );
 
+    my ( $bold, $reset ) = ( color( 'bold' ), color( 'reset' ) );
+    print "$bold$cname$reset" . ( eval { " -- " . $wire->get( '$summary' ) } || '' ) . "\n";
+
     my $config = $wire->config;
-    my @services;
+    my %services;
     for my $name ( keys %$config ) {
-        push @services, _list_service( $wire, $name, $config->{$name} );
+        my ( $name, $abstract ) = _list_service( $wire, $name, $config->{$name} );
+        next unless $name;
+        $services{ $name } = $abstract;
     }
-    print join( "\n", sort @services ), "\n";
+    my $size = max map { length } keys %services;
+    print join( "\n", map { sprintf "- $bold%-${size}s$reset -- %s", $_, $services{ $_ } } sort keys %services ), "\n";
     return 0;
 }
 
@@ -155,17 +175,29 @@ sub _list_service {
 
 #=sub _get_service_info( $name, $class )
 #
-#   my $info_str = _get_service_info( $name, $class );
+#   my ( $name, $abstract ) = _get_service_info( $name, $class );
 #
-# Get the information about the given service. Presently returns the
-# name, but in the future will look in the class for some documentation
-# about the service.
+# Get the information about the given service. Opens the C<$class>
+# documentation to find the class's abstract (the C<=head1 NAME>
+# section).
 #
 #=cut
 
 sub _get_service_info {
     my ( $name, $class ) = @_;
-    return $name;
+    my $pod_path = pod_where( { -inc => 1 }, $class );
+    return $name, $class unless $pod_path;
+
+    my $pod_root = Pod::Simple::SimpleTree->new->parse_file( $pod_path )->root;
+    #; use Data::Dumper;
+    #; print Dumper $pod_root;
+    my @nodes = @{$pod_root}[2..$#$pod_root];
+    #; print Dumper \@nodes;
+    my ( $name_i ) = grep { $nodes[$_][0] eq 'head1' && $nodes[$_][2] eq 'NAME' } 0..$#nodes;
+    return $name, $class unless defined $name_i;
+
+    my $abstract = $nodes[ $name_i + 1 ][2];
+    return $name, $abstract;
 }
 
 1;
@@ -180,7 +212,7 @@ Beam::Runner::Command::list - List the available containers and services
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -190,8 +222,9 @@ version 0.002
 =head1 DESCRIPTION
 
 List the available containers found in the directories defined in
-C<BEAM_PATH>, or list the runnable services found in the given
-container.
+C<BEAM_PATH>, and list the runnable services found in them. Also show
+the C<$summary> from the container file, and the abstract from every
+service.
 
 When listing services, this command must load every single class
 referenced in the container, but it will not instanciate any object.
