@@ -1,5 +1,5 @@
 package Beam::Runner::Util;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: Utilities for Beam::Runner command classes
 
 #pod =head1 SYNOPSIS
@@ -30,6 +30,10 @@ our @EXPORT_OK = qw( find_container_path );
 # to say the extension is given by the user's input)
 our @EXTS = ( "", qw( .yml .yaml .json .xml .pl ) );
 
+# The "BEAM_PATH" separator value. Windows uses ';' to separate
+# PATH-like variables, everything else uses ':'
+our $PATHS_SEP = $^O eq 'MSWin32' ? ';' : ':';
+
 #pod =sub find_container_path
 #pod
 #pod     my $path = find_container_path( $container_name );
@@ -53,7 +57,7 @@ sub find_container_path {
 
     my @dirs = ( "." );
     if ( $ENV{BEAM_PATH} ) {
-        push @dirs, split /:/, $ENV{BEAM_PATH};
+        push @dirs, split /$PATHS_SEP/, $ENV{BEAM_PATH};
     }
 
     DIR: for my $dir ( @dirs ) {
@@ -68,7 +72,7 @@ sub find_container_path {
     }
 
     die sprintf qq{Could not find container "%s" in directories: %s\n},
-        $container, join( ":", @dirs )
+        $container, join( $PATHS_SEP, @dirs )
         unless $path;
 
     return $path;
@@ -86,7 +90,7 @@ Beam::Runner::Util - Utilities for Beam::Runner command classes
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
